@@ -10,27 +10,13 @@
 #  License for the specific language governing permissions and limitations
 #  under the License.
 
-"""Special argparse module that allows to bypass abbrev mode."""
+"""Overrides of standard argparse behavior."""
 
-from __future__ import absolute_import
-from argparse import *  # noqa
 import argparse
-import sys
 import warnings
 
 
-class ArgumentParser(argparse.ArgumentParser):
-
-    if sys.version_info < (3, 5):
-        def __init__(self, *args, **kwargs):
-            self.allow_abbrev = kwargs.pop("allow_abbrev", True)
-            super(ArgumentParser, self).__init__(*args, **kwargs)
-
-        def _get_option_tuples(self, option_string):
-            if self.allow_abbrev:
-                return super(ArgumentParser, self)._get_option_tuples(
-                    option_string)
-            return ()
+class _ArgumentContainerMixIn(object):
 
     # NOTE(dhellmann): We have to override the methods for creating
     # groups to return our objects that know how to deal with the
@@ -55,6 +41,11 @@ class ArgumentParser(argparse.ArgumentParser):
         )
 
 
+class ArgumentParser(_ArgumentContainerMixIn, argparse.ArgumentParser):
+
+    pass
+
+
 def _handle_conflict_ignore(container, option_string_actions,
                             new_action, conflicting_actions):
 
@@ -84,23 +75,31 @@ def _handle_conflict_ignore(container, option_string_actions,
             )
 
 
-class _ArgumentGroup(argparse._ArgumentGroup):
-
-    def _handle_conflict_ignore(self, action, conflicting_actions):
-        _handle_conflict_ignore(
-            self,
-            self._option_string_actions,
-            action,
-            conflicting_actions,
-        )
+class _ArgumentGroup(_ArgumentContainerMixIn, argparse._ArgumentGroup):
+    pass
 
 
-class _MutuallyExclusiveGroup(argparse._MutuallyExclusiveGroup):
+class _MutuallyExclusiveGroup(_ArgumentContainerMixIn,
+                              argparse._MutuallyExclusiveGroup):
+    pass
 
-    def _handle_conflict_ignore(self, action, conflicting_actions):
-        _handle_conflict_ignore(
-            self,
-            self._option_string_actions,
-            action,
-            conflicting_actions,
-        )
+
+class SmartHelpFormatter(argparse.HelpFormatter):
+    """Smart help formatter to output raw help message if help contain \n.
+
+    Some command help messages maybe have multiple line content, the built-in
+    argparse.HelpFormatter wrap and split the content according to width, and
+    ignore \n in the raw help message, it merge multiple line content in one
+    line to output, that looks messy. SmartHelpFormatter keep the raw help
+    message format if it contain \n, and wrap long line like HelpFormatter
+    behavior.
+    """
+
+    def _split_lines(self, text, width):
+        lines = text.splitlines() if '\n' in text else [text]
+        wrap_lines = []
+        for each_line in lines:
+            wrap_lines.extend(
+                super(SmartHelpFormatter, self)._split_lines(each_line, width)
+            )
+        return wrap_lines
